#!/usr/bin/env python

# This is a utility script to purge images that have been removed from glance
# from the mysql database.
# It's a general purpose helper script that was included here for convenience.
# Please run this on the glance unit as it has access to the mysql host by
# default.

# Copyright 2016 Canonical Ltd.
# Author: Manuel Seelaus <manuel.seelaus@canonical.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License version 3, as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
# SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.

import MySQLdb
import sys
import urlparse

config = {}

# pull connection information from glance-api.conf
try:
    with open('/etc/glance/glance-api.conf', 'r') as conf_file:
        for line in conf_file.readlines():
            if line.startswith('connection ='):
                # connection = mysql://glance:<password>@<host>/glance
                connection = urlparse.urlparse(line.split('=')[1].strip())
                config['host'] = connection.hostname
                config['user'] = connection.username
                config['password'] = connection.password
                config['database'] = connection.path[1:].strip()
                break
except IOError as e:
    sys.exit(e)

try:
    connection = MySQLdb.connect(host=config['host'],
                                 user=config['user'],
                                 passwd=config['password'],
                                 db=config['database'])
except Exception as e:
    print("ERROR: unable to connect to mysql database")
    sys.exit(e)

cursor = connection.cursor()

# delete from images where status = 'deleted'
cursor.execute("SELECT id FROM glance.images WHERE status='deleted';")
image_ids = cursor.fetchall()

for image_id in image_ids:
    print("purging {}".format(image_id[0]))
    args = (image_id[0])
    commands = ["DELETE FROM glance.image_properties WHERE image_id=%s;",
                "DELETE FROM glance.image_members WHERE image_id=%s;",
                "DELETE FROM glance.image_tags WHERE image_id=%s;",
                "DELETE FROM glance.image_locations WHERE image_id=%s;",
                "DELETE FROM glance.images WHERE id=%s;"]

    for command in commands:
        cursor.execute(command, args)
    connection.commit()

cursor.close()
connection.close()
